Cheshire3 Object Model - User
=============================

.. _objects-user-api:

API
---

.. autoclass:: cheshire3.baseObjects.User
   :members:


.. _objects-user-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.user.SimpleUser
   :members: